Crate rclone_sdk

Crate rclone_sdk 

Re-exports

pub use overrides::*;

Modules

overrides
Hand-written overrides for the generated client. Survives regeneration; the gen script wires it in via pub mod overrides;.
prelude
Items consumers will typically use such as the Client.
types
Types used as operation parameters and responses.

Structs

ByteStream
Untyped byte stream used for both success and error responses.
Client
Client for Rclone RC API
ResponseValue
Typed value returned by generated client methods.

Enums

Error
Error produced by generated client methods.

Traits

ClientInfo
Interface for which an implementation is generated for all clients.