pub struct CacheExpireRequest {
pub async_: Option<bool>,
pub group: Option<String>,
pub remote: Option<String>,
pub with_data: Option<bool>,
}Expand description
CacheExpireRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"remote": {
"description": "Remote path to expire from the cache, e.g.
`remote:path/to/dir`.",
"type": "string"
},
"withData": {
"description": "Set to true to drop cached chunk data along with
directory entries.",
"type": "boolean"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
group: Option<String>Assign the request to a custom stats group.
remote: Option<String>Remote path to expire from the cache, e.g. remote:path/to/dir.
with_data: Option<bool>Set to true to drop cached chunk data along with directory entries.