pub struct DebugSetSoftMemoryLimitRequest {
pub async_: Option<bool>,
pub group: Option<String>,
pub mem_limit: Option<i64>,
}Expand description
DebugSetSoftMemoryLimitRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"mem-limit": {
"description": "Soft memory limit for the Go runtime in bytes.",
"type": "integer"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
group: Option<String>Assign the request to a custom stats group.
mem_limit: Option<i64>Soft memory limit for the Go runtime in bytes.