pub struct JobBatchRequest {
pub async_: Option<bool>,
pub concurrency: Option<i64>,
pub inputs: Vec<JobBatchRequestInputsItem>,
}Expand description
JobBatchRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"concurrency": {
"description": "Do this many commands concurrently. Defaults to
--transfers if not set.",
"type": "integer"
},
"inputs": {
"description": "List of inputs to the commands with an extra _path
parameter.",
"type": "array",
"items": {
"type": "object",
"required": [
"_path"
],
"properties": {
"_path": {
"description": "rc/path",
"type": "string"
}
},
"additionalProperties": true
}
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
concurrency: Option<i64>Do this many commands concurrently. Defaults to –transfers if not set.
inputs: Vec<JobBatchRequestInputsItem>List of inputs to the commands with an extra _path parameter.