pub struct MountMountRequest {
pub async_: Option<bool>,
pub config: Option<String>,
pub filter: Option<String>,
pub fs: Option<String>,
pub group: Option<String>,
pub mount_opt: Option<String>,
pub mount_point: Option<String>,
pub mount_type: Option<String>,
pub vfs_opt: Option<String>,
}Expand description
MountMountRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_config": {
"description": "JSON encoded config overrides applied for this call
only.",
"type": "string"
},
"_filter": {
"description": "JSON encoded filter overrides applied for this call
only.",
"type": "string"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote path to mount, such as `drive:` or
`remote:subdir`.",
"type": "string"
},
"mountOpt": {
"description": "Mount options encoded as JSON, matching flags
accepted by `rclone mount`.",
"type": "string"
},
"mountPoint": {
"description": "Absolute local path where the remote should be
mounted.",
"type": "string"
},
"mountType": {
"description": "Optional mount implementation to use (`mount`,
`cmount`, or `mount2`).",
"type": "string"
},
"vfsOpt": {
"description": "VFS options encoded as JSON, matching flags
accepted by `rclone mount`.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
config: Option<String>JSON encoded config overrides applied for this call only.
filter: Option<String>JSON encoded filter overrides applied for this call only.
fs: Option<String>Remote path to mount, such as drive: or remote:subdir.
group: Option<String>Assign the request to a custom stats group.
mount_opt: Option<String>Mount options encoded as JSON, matching flags accepted by rclone mount.
mount_point: Option<String>Absolute local path where the remote should be mounted.
mount_type: Option<String>Optional mount implementation to use (mount, cmount, or
mount2).
vfs_opt: Option<String>VFS options encoded as JSON, matching flags accepted by rclone mount.