pub struct OperationsCopyurlRequest {
pub async_: Option<bool>,
pub auto_filename: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub remote: Option<String>,
pub url: Option<String>,
}Expand description
OperationsCopyurlRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"autoFilename": {
"description": "Set to true to derive the destination filename from
the URL.",
"type": "boolean"
},
"fs": {
"description": "Remote name or path that will receive the
downloaded file, e.g. `drive:`.",
"type": "string"
},
"remote": {
"description": "Destination path within `fs` where the fetched
object will be stored.",
"type": "string"
},
"url": {
"description": "Source URL to fetch the object from.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
auto_filename: Option<bool>Set to true to derive the destination filename from the URL.
fs: Option<String>Remote name or path that will receive the downloaded file, e.g.
drive:.
group: Option<String>Assign the request to a custom stats group.
remote: Option<String>Destination path within fs where the fetched object will be
stored.
url: Option<String>Source URL to fetch the object from.