pub struct OperationsDeletefileRequest {
pub async_: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub remote: Option<String>,
}Expand description
OperationsDeletefileRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote name or path that contains the file to
delete.",
"type": "string"
},
"remote": {
"description": "Exact path to the file within `fs` that should be
deleted.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
fs: Option<String>Remote name or path that contains the file to delete.
group: Option<String>Assign the request to a custom stats group.
remote: Option<String>Exact path to the file within fs that should be deleted.