pub struct OperationsHashsumfileRequest {
pub async_: Option<bool>,
pub base64: Option<bool>,
pub download: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub hash_type: Option<String>,
pub remote: Option<String>,
}Expand description
OperationsHashsumfileRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"base64": {
"description": "Set to true to emit the hash value in base64 rather
than hexadecimal.",
"type": "boolean"
},
"download": {
"description": "Set to true to force reading the data instead of
using remote checksums.",
"type": "boolean"
},
"fs": {
"description": "Remote name or path containing the file to hash.",
"type": "string"
},
"hashType": {
"description": "Hash algorithm to use, e.g. `md5`, `sha1`, or
another supported name.",
"type": "string"
},
"remote": {
"description": "Path to the specific file within `fs` to hash.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
base64: Option<bool>Set to true to emit the hash value in base64 rather than hexadecimal.
download: Option<bool>Set to true to force reading the data instead of using remote checksums.
fs: Option<String>Remote name or path containing the file to hash.
group: Option<String>Assign the request to a custom stats group.
hash_type: Option<String>Hash algorithm to use, e.g. md5, sha1, or another supported
name.
remote: Option<String>Path to the specific file within fs to hash.