pub struct OperationsMovefileRequest {
pub async_: Option<bool>,
pub dst_fs: Option<String>,
pub dst_remote: Option<String>,
pub group: Option<String>,
pub src_fs: Option<String>,
pub src_remote: Option<String>,
}Expand description
OperationsMovefileRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"dstFs": {
"description": "Destination remote name or path where the file will
be moved.",
"type": "string"
},
"dstRemote": {
"description": "Destination path within `dstFs` for the moved
object.",
"type": "string"
},
"srcFs": {
"description": "Source remote name or path containing the file to
move.",
"type": "string"
},
"srcRemote": {
"description": "Path to the source object within `srcFs`.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
dst_fs: Option<String>Destination remote name or path where the file will be moved.
dst_remote: Option<String>Destination path within dstFs for the moved object.
group: Option<String>Assign the request to a custom stats group.
src_fs: Option<String>Source remote name or path containing the file to move.
src_remote: Option<String>Path to the source object within srcFs.