pub struct OperationsPubliclinkRequest {
pub async_: Option<bool>,
pub expire: Option<String>,
pub fs: Option<String>,
pub group: Option<String>,
pub remote: Option<String>,
pub unlink: Option<bool>,
}Expand description
OperationsPubliclinkRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"expire": {
"description": "Optional expiration time for the public link,
formatted as supported by the backend.",
"type": "string"
},
"fs": {
"description": "Remote name or path hosting the object for which to
manage a public link.",
"type": "string"
},
"remote": {
"description": "Path within `fs` to the object for which to create
or remove a public link.",
"type": "string"
},
"unlink": {
"description": "Set to true to remove an existing public link
instead of creating one.",
"type": "boolean"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
expire: Option<String>Optional expiration time for the public link, formatted as supported by the backend.
fs: Option<String>Remote name or path hosting the object for which to manage a public link.
group: Option<String>Assign the request to a custom stats group.
remote: Option<String>Path within fs to the object for which to create or remove a
public link.
unlink: Option<bool>Set to true to remove an existing public link instead of creating one.