pub struct OperationsPurgeRequest {
pub async_: Option<bool>,
pub config: Option<String>,
pub filter: Option<String>,
pub fs: Option<String>,
pub group: Option<String>,
pub remote: Option<String>,
}Expand description
OperationsPurgeRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_config": {
"description": "JSON encoded config overrides applied for this call
only.",
"type": "string"
},
"_filter": {
"description": "JSON encoded filter overrides applied for this call
only.",
"type": "string"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote name or path from which to remove all
contents.",
"type": "string"
},
"remote": {
"description": "Path within `fs` whose contents should be purged.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
config: Option<String>JSON encoded config overrides applied for this call only.
filter: Option<String>JSON encoded filter overrides applied for this call only.
fs: Option<String>Remote name or path from which to remove all contents.
group: Option<String>Assign the request to a custom stats group.
remote: Option<String>Path within fs whose contents should be purged.