pub struct OperationsRmdirsRequest {
pub async_: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub leave_root: Option<bool>,
pub remote: Option<String>,
}Expand description
OperationsRmdirsRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote name or path to scan for empty
directories.",
"type": "string"
},
"leaveRoot": {
"description": "Set to true to preserve the top-level directory
even if empty.",
"type": "boolean"
},
"remote": {
"description": "Path within `fs` whose empty subdirectories should
be removed.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
fs: Option<String>Remote name or path to scan for empty directories.
group: Option<String>Assign the request to a custom stats group.
leave_root: Option<bool>Set to true to preserve the top-level directory even if empty.
remote: Option<String>Path within fs whose empty subdirectories should be removed.