pub struct OperationsSettierRequest {
pub async_: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
}Expand description
OperationsSettierRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote name or path whose storage class tier should
be changed.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
fs: Option<String>Remote name or path whose storage class tier should be changed.
group: Option<String>Assign the request to a custom stats group.