pub struct OperationsStatRequest {
pub async_: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub opt: Option<String>,
pub remote: Option<String>,
}Expand description
OperationsStatRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Remote name or path that contains the item to
inspect.",
"type": "string"
},
"opt": {
"description": "Optional JSON object of listing flags, matching
those accepted by `operations/list`.",
"type": "string"
},
"remote": {
"description": "Path to the file or directory within `fs` to
describe.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
fs: Option<String>Remote name or path that contains the item to inspect.
group: Option<String>Assign the request to a custom stats group.
opt: Option<String>Optional JSON object of listing flags, matching those accepted by
operations/list.
remote: Option<String>Path to the file or directory within fs to describe.