pub struct OptionsLocalRequest {
pub async_: Option<bool>,
pub config: Option<String>,
pub filter: Option<String>,
pub group: Option<String>,
}Expand description
OptionsLocalRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_config": {
"description": "JSON encoded config overrides applied for this call
only.",
"type": "string"
},
"_filter": {
"description": "JSON encoded filter overrides applied for this call
only.",
"type": "string"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
config: Option<String>JSON encoded config overrides applied for this call only.
filter: Option<String>JSON encoded filter overrides applied for this call only.
group: Option<String>Assign the request to a custom stats group.