pub struct ServeStartRequest {
pub addr: Option<String>,
pub async_: Option<bool>,
pub config: Option<String>,
pub filter: Option<String>,
pub fs: Option<String>,
pub group: Option<String>,
pub type_: Option<String>,
}Expand description
ServeStartRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_config": {
"description": "JSON encoded config overrides applied for this call
only.",
"type": "string"
},
"_filter": {
"description": "JSON encoded filter overrides applied for this call
only.",
"type": "string"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"addr": {
"description": "Address and port to bind the server to, such as
`:5572` or `localhost:8080`.",
"type": "string"
},
"fs": {
"description": "Remote path that will be served.",
"type": "string"
},
"type": {
"description": "Type of server to start (e.g. `http`, `webdav`,
`ftp`, `sftp`).",
"type": "string"
}
},
"additionalProperties": true
}Fields
addr: Option<String>Address and port to bind the server to, such as :5572 or
localhost:8080.
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
config: Option<String>JSON encoded config overrides applied for this call only.
filter: Option<String>JSON encoded filter overrides applied for this call only.
fs: Option<String>Remote path that will be served.
group: Option<String>Assign the request to a custom stats group.
type_: Option<String>Type of server to start (e.g. http, webdav, ftp, sftp).