pub struct SyncMoveRequest {
pub async_: Option<bool>,
pub config: Option<String>,
pub create_empty_src_dirs: Option<bool>,
pub delete_empty_src_dirs: Option<bool>,
pub dst_fs: Option<String>,
pub filter: Option<String>,
pub group: Option<String>,
pub src_fs: Option<String>,
}Expand description
SyncMoveRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_config": {
"description": "JSON encoded config overrides applied for this call
only.",
"type": "string"
},
"_filter": {
"description": "JSON encoded filter overrides applied for this call
only.",
"type": "string"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"createEmptySrcDirs": {
"description": "Set to true to create empty source directories on
the destination.",
"type": "boolean"
},
"deleteEmptySrcDirs": {
"description": "Set to true to delete empty directories from the
source after the move completes.",
"type": "boolean"
},
"dstFs": {
"description": "Destination remote path that will receive moved
files.",
"type": "string"
},
"srcFs": {
"description": "Source remote path whose contents will be moved.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
config: Option<String>JSON encoded config overrides applied for this call only.
create_empty_src_dirs: Option<bool>Set to true to create empty source directories on the destination.
delete_empty_src_dirs: Option<bool>Set to true to delete empty directories from the source after the move completes.
dst_fs: Option<String>Destination remote path that will receive moved files.
filter: Option<String>JSON encoded filter overrides applied for this call only.
group: Option<String>Assign the request to a custom stats group.
src_fs: Option<String>Source remote path whose contents will be moved.