pub struct VfsPollIntervalRequest {
pub async_: Option<bool>,
pub fs: Option<String>,
pub group: Option<String>,
pub interval: Option<String>,
pub timeout: Option<String>,
}Expand description
VfsPollIntervalRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"fs": {
"description": "Optional VFS identifier whose poll interval should
be queried or modified.",
"type": "string"
},
"interval": {
"description": "Duration string (e.g. `5m`) to set as the new poll
interval.",
"type": "string"
},
"timeout": {
"description": "Duration to wait for the poll interval change to
take effect; `0` waits indefinitely.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
fs: Option<String>Optional VFS identifier whose poll interval should be queried or modified.
group: Option<String>Assign the request to a custom stats group.
interval: Option<String>Duration string (e.g. 5m) to set as the new poll interval.
timeout: Option<String>Duration to wait for the poll interval change to take effect; 0
waits indefinitely.