Skip to main contentCrate rclone_sdk
Source pub use overrides::*;
- overrides
- Hand-written overrides for the generated client. Survives regeneration; the
gen script wires it in via
pub mod overrides;. - prelude
- Items consumers will typically use such as the Client.
- types
- Types used as operation parameters and responses.
- ByteStream
- Untyped byte stream used for both success and error responses.
- Client
- Client for Rclone RC API
- ResponseValue
- Typed value returned by generated client methods.
- Error
- Error produced by generated client methods.
- ClientInfo
- Interface for which an implementation is generated for all clients.