pub struct OperationsCheckRequest {Show 15 fields
pub async_: Option<bool>,
pub check_file_fs: Option<String>,
pub check_file_hash: Option<String>,
pub check_file_remote: Option<String>,
pub combined: Option<bool>,
pub differ: Option<bool>,
pub download: Option<bool>,
pub dst_fs: Option<String>,
pub error: Option<bool>,
pub group: Option<String>,
pub match_: Option<bool>,
pub missing_on_dst: Option<bool>,
pub missing_on_src: Option<bool>,
pub one_way: Option<bool>,
pub src_fs: Option<String>,
}Expand description
OperationsCheckRequest
JSON schema
{
"type": "object",
"properties": {
"_async": {
"description": "Run the command asynchronously. Returns a job id
immediately.",
"type": "boolean"
},
"_group": {
"description": "Assign the request to a custom stats group.",
"type": "string"
},
"checkFileFs": {
"description": "Remote containing the checksum SUM file when using
`checkFileHash`.",
"type": "string"
},
"checkFileHash": {
"description": "Hash name to expect in the supplied SUM file, such
as `md5`.",
"type": "string"
},
"checkFileRemote": {
"description": "Path within `checkFileFs` to the checksum SUM
file.",
"type": "string"
},
"combined": {
"description": "Set to true to include a combined summary report in
the response.",
"type": "boolean"
},
"differ": {
"description": "Set to true to include differing files in the
report.",
"type": "boolean"
},
"download": {
"description": "Set to true to read file contents during comparison
instead of relying on hashes.",
"type": "boolean"
},
"dstFs": {
"description": "Destination remote name or path that should match
the source.",
"type": "string"
},
"error": {
"description": "Set to true to include entries that encountered
errors.",
"type": "boolean"
},
"match": {
"description": "Set to true to include matching files in the
report.",
"type": "boolean"
},
"missingOnDst": {
"description": "Set to true to report files missing from the
destination.",
"type": "boolean"
},
"missingOnSrc": {
"description": "Set to true to report files missing from the
source.",
"type": "boolean"
},
"oneWay": {
"description": "Set to true to only ensure that source files exist
on the destination.",
"type": "boolean"
},
"srcFs": {
"description": "Source remote name or path to verify, e.g.
`drive:`.",
"type": "string"
}
}
}Fields
async_: Option<bool>Run the command asynchronously. Returns a job id immediately.
check_file_fs: Option<String>Remote containing the checksum SUM file when using checkFileHash.
check_file_hash: Option<String>Hash name to expect in the supplied SUM file, such as md5.
check_file_remote: Option<String>Path within checkFileFs to the checksum SUM file.
combined: Option<bool>Set to true to include a combined summary report in the response.
differ: Option<bool>Set to true to include differing files in the report.
download: Option<bool>Set to true to read file contents during comparison instead of relying on hashes.
dst_fs: Option<String>Destination remote name or path that should match the source.
error: Option<bool>Set to true to include entries that encountered errors.
group: Option<String>Assign the request to a custom stats group.
match_: Option<bool>Set to true to include matching files in the report.
missing_on_dst: Option<bool>Set to true to report files missing from the destination.
missing_on_src: Option<bool>Set to true to report files missing from the source.
one_way: Option<bool>Set to true to only ensure that source files exist on the destination.
src_fs: Option<String>Source remote name or path to verify, e.g. drive:.